PlsRegressionParams

Struct PlsRegressionParams 

pub struct PlsRegressionParams<F: Float>(/* private fields */);

Implementations

Source

impl<F: Float> PlsRegressionParams<F>

pub fn max_iterations(self, max_iter: usize) -> Self

Set the maximum number of iterations of the power method when algorithm=‘Nipals’. Ignored otherwise.

pub fn tolerance(self, tolerance: F) -> Self

Set the tolerance used as convergence criteria in the power method: the algorithm stops whenever the squared norm of u_i - u_{i-1} is less than tol, where u corresponds to the left singular vector.

pub fn scale(self, scale: bool) -> Self

Set whether to scale the dataset

pub fn algorithm(self, algorithm: Algorithm) -> Self

Set the algorithm used to estimate the first singular vectors of the cross-covariance matrix. Nipals uses the power method while Svd will compute the whole SVD.